@@ -127,18 +127,21 @@ class DeltaTable:
         self.columns = self._get_column_list(column_list)
         self.kw = kw
         self.etl_code_stmts = self.create_table_etl_code()
-        self.set_default_columns()
 
-    def set_default_columns(self, default_columns = None) -> None:
-        """
-        set the default columns
-        """
-        if default_columns is None:
-            self.default_columns = self._DEFAULT_COLUMNS
-        elif default_columns == []:
-            self.default_columns = []
-        else:
-            self.default_columns = default_columns
+    # def set_default_columns(self, default_columns = None) -> None:
+    #     """
+    #     set the default columns
+    #     """
+    #     if default_columns is None:
+    #         self.default_columns = self._DEFAULT_COLUMNS
+    #     elif default_columns == []:
+    #         self.default_columns = []
+    #     else:
+    #         self.default_columns = default_columns
+
+    @property
+    def default_columns(self) -> List[DeltaTableColumn]:
+        return self._DEFAULT_COLUMNS
 
     def _get_column_list(self, column_list):
         column_list.extend(self.default_columns)
